==> php-residence_0.2.4.tar.gz: php-residence/visualizza_contratto.php <==
<html>
<header>
<title> </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "visualizza_contratto.php";
include ("dati/connessione_db.php");
include ("includes/funzioni.php");
$stile_soldi = stile_soldi();

$cognome = stripslashes($cognome);
$nome = stripslashes($nome);
$cognome2 = stripslashes($cognome2);
$nome2 = stripslashes($nome2);
$nazione = stripslashes($nazione);
$citta = stripslashes($citta);
$via = stripslashes($via);
$commento = stripslashes($commento);

if ($tariffa_selezionata) {
$c_tot_selez = "c_tot_selez" . $tariffa_selezionata;
if ($$c_tot_selez) $costo_tot = $$c_tot_selez;
$c_tariffa_selez = "c_tariffa_selez" . $tariffa_selezionata;
if ($$c_tariffa_selez) $costo_tariffa = $$c_tariffa_selez;
$n_tariffa_selez = "n_tariffa_selez" . $tariffa_selezionata;
if ($$n_tariffa_selez) $nome_tariffa = $$n_tariffa_selez;
} # fine if ($tariffa_selezionata)

$oggi = date("j/n/Y");

if ($sesso == "f") {
$il = "la";
$al = "alla";
$e = "a";
$o = "a";
$Mr = "s";
} # fine if ($sesso == "f")
else {
$il = "il";
$al = "al";
$a = "";
$o = "o";
$Mr = "";
} # fine else if ($sesso == "f")

if ($sesso2 == "f") {
$il2 = "la";
$al2 = "alla";
$e2 = "a";
$o2 = "a";
$Mr2 = "s";
} # fine if ($sesso2 == "f")
else {
$il2 = "il";
$al2 = "al";
$a2 = "";
$o2 = "o";
$Mr2 = "";
} # fine else if ($sesso2 == "f")

if (!$nome) { $nome = "<b>____________________</b>"; }
if (!$nome2) { $nome2 = "<b>____________________</b>"; }
if (!$cognome) { $cognome = "<b>_________________</b>"; }
if (!$cognome2) { $cognome2 = "<b>_________________</b>"; }
if (!$datanascita) { $datanascita = "<b>______________</b>"; }
if (!$datanascita2) { $datanascita2 = "<b>______________</b>"; }
if (!$nazione) { $nazione = "<b>_____________</b>"; }
if (!$citta) { $citta = "<b>___________________</b>"; }
if (!$via) { $via2 = mex("via",$pag)." <b>________________________________</b>"; }
else { $via2 = $via; }
if (!$via) { $via = "<b>________________________________</b>"; }
if (!$numcivico) { $numcivico = "<b>_____</b>"; }
if (!$telefono) { $telefono = "<b>__________________</b>"; }
if (!$telefono2) { $telefono2 = "<b>__________________</b>"; }
if (!$telefono3) { $telefono3 = "<b>__________________</b>"; }
if (!$fax) { $fax = "<b>__________________</b>"; }
if (!$email) { $email = "<b>__________________</b>"; }
if (!$cap) { $cap = "<b>________</b>"; }
if ($num_persone == "non specificato" or $num_persone == "") {
$num_persone = "<b>_____</b>";
$num_persone_tot = "<b>_____</b>";
} # fine if ($num_persone == "non specificato" or $num_persone == "")
else { $num_persone_tot = $num_persone + $n_letti_agg; }
if ($costo_tot and $caparra) {
$resto_caparra = $costo_tot - $caparra;
$resto_caparra_p = punti_in_num($resto_caparra,$stile_soldi);
} # fine if ($costo_tot and $caparra)
else {
$resto_caparra = "<b>_____________</b>";
$resto_caparra_p = "<b>_____________</b>";
} # fine else if ($costo_tot and $caparra)
if (!$caparra or $caparra == 0) {
$caparra = "<b>___________</b>";
$caparra_p = "<b>___________</b>";
} # fine if (!$caparra or $caparra == 0)
else { $caparra_p = punti_in_num($caparra,$stile_soldi); }
if (!$data_inizio) { $data_inizio = "<b>______________</b>"; }
if (!$data_fine) { $data_fine = "<b>______________</b>"; }
if (!$nome_tariffa) { $nome_tariffa = "<b>____________________</b>"; }
if (!$costo_tariffa) {
$costo_tariffa = "<b>____________________</b>";
$costo_tariffa_p = "<b>____________________</b>";
} # fine if (!$costo_tariffa)
else { $costo_tariffa_p = punti_in_num($costo_tariffa,$stile_soldi); }
if (!$sconto) {
$sconto = "<b>____________</b>";
$sconto_p = "<b>____________</b>";
} # fine if (!$sconto)
else { $sconto_p = punti_in_num($sconto,$stile_soldi); }
if (!$commento) { $commento = "<b>______________________</b>"; }
if (!$appartamento) { $appartamento = "<b>____</b>"; }
if (!$app_assegnabili) { $app_assegnabili = "<b>_________________</b>"; }
if (!$pagato) {
$pagato = "<b>_____________</b>";
$pagato_p = "<b>_____________</b>";
} # fine if (!$pagato)
else { $pagato_p = punti_in_num($pagato,$stile_soldi); }
if (!$costo_tot) {
$costo_tot = "<b>_____________</b>";
$costo_tot_p = "<b>_____________</b>";
} # fine if (!$costo_tot)
else { $costo_tot_p = punti_in_num($costo_tot,$stile_soldi); }
if (!$n_letti_agg) { $n_letti_agg = "<b>____</b>"; }

for ($numca = 0 ; $numca < $d_num_costi_aggiuntivi ; $numca = $numca + 1) {
$nome_costo_agg = nome_costo_agg . $numca;
$nome_costo_agg = $$nome_costo_agg;
$val_costo_agg = val_costo_agg . $numca;
$val_costo_agg = $$val_costo_agg;
$val_costo_agg_p = punti_in_num($val_costo_agg,$stile_soldi);
$tutti_i_costi_agg .= "$nome_costo_agg: $val_costo_agg<br>";
$tutti_i_costi_agg_p .= "$nome_costo_agg: $val_costo_agg_p<br>";
if ($num_costo_agg_sel == $numca) {
$nome_costo_agg_sel = $nome_costo_agg;
$valore_costo_agg_sel = $val_costo_agg;
$valore_costo_agg_sel_p = $val_costo_agg_p;
} # fine if ($num_costo_agg_sel == $numca)
} # fine for $numca

$surname = $cognome;
$name = $nome;
$birthday = $datanascita;
$nation = $nazione;
$city = $citta;
$street = $via;
$street2 = $via2;
$street_number = $numcivico;
$postal_code = $cap;
$telephone = $telefono;
$telephone2 = $telefono2;
$telephone3 = $telefono3;
$surname2 = $cognome2;
$name2 = $nome2;
$birthday2 = $datanascita2;
$people_num = $num_persone;
$extra_beds_num = $n_letti_agg;
$people_num_tot = $num_persone_tot;
$fare_tot = $costo_tot;
$deposit = $caparra;
$deposit_rest = $resto_caparra;
$starting_date = $data_inizio;
$ending_date = $data_fine;
$fare_name = $nome_tariffa;
$fare_price = $costo_tariffa;
$discount = $sconto;
$comment = $commento;
$apartment = $appartamento;
$apartment_list = $app_assegnabili;
$paid = $pagato;
$all_extra_costs = $tutti_i_costi_agg;
$sel_extra_cost_name = $nome_costo_agg_sel;
$sel_extra_cost_value = $valore_costo_agg_sel;
$today = $oggi;
$fare_tot_p = $costo_tot_p;
$deposit_p = $caparra_p;
$paid_p = $pagato_p;
$deposit_rest_p = $resto_caparra_p;
$fare_price_p = $costo_tariffa_p;
$all_extra_costs_p = $tutti_i_costi_agg_p;
$sel_extra_cost_value_p = $valore_costo_agg_sel_p;
$discount_p = $sconto_p;

if ($tipo_contratto == 1) { include ("contr/contr01.php"); }
if ($tipo_contratto == 2) { include ("contr/contr02.php"); }
if ($tipo_contratto == 3) { include ("contr/contr03.php"); }
if ($tipo_contratto == 4) { include ("contr/contr04.php"); }
if ($tipo_contratto == 5) { include ("contr/contr05.php"); }
if ($tipo_contratto == 6) { include ("contr/contr06.php"); }
if ($tipo_contratto == 7) { include ("contr/contr07.php"); }
if ($tipo_contratto == 8) { include ("contr/contr08.php"); }
if ($tipo_contratto == 9) { include ("contr/contr09.php"); }
if ($tipo_contratto == 10) { include ("contr/contr10.php"); }
if ($tipo_contratto == 11) { include ("contr/contr11.php"); }
if ($tipo_contratto == 12) { include ("contr/contr12.php"); }
if ($tipo_contratto == 13) { include ("contr/contr13.php"); }
if ($tipo_contratto == 14) { include ("contr/contr14.php"); }
if ($tipo_contratto == 15) { include ("contr/contr15.php"); }
if ($tipo_contratto == 16) { include ("contr/contr16.php"); }
if ($tipo_contratto == 17) { include ("contr/contr17.php"); }
if ($tipo_contratto == 18) { include ("contr/contr18.php"); }


echo $contratto;

?>

</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/visualizza_contratto.php <==
<html>
<header>
<title> </title>
</header>
<body bgcolor=#ffffff>

<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "visualizza_contratto.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
$stile_soldi = stile_soldi();

$cognome = stripslashes($cognome);
$nome = stripslashes($nome);
$cognome2 = stripslashes($cognome2);
$nome2 = stripslashes($nome2);
$nazione = stripslashes($nazione);
$citta = stripslashes($citta);
$via = stripslashes($via);
$commento = stripslashes($commento);

if ($tariffa_selezionata) {
$c_tot_selez = "c_tot_selez" . $tariffa_selezionata;
if ($$c_tot_selez) $costo_tot = $$c_tot_selez;
$c_tariffa_selez = "c_tariffa_selez" . $tariffa_selezionata;
if ($$c_tariffa_selez) $costo_tariffa = $$c_tariffa_selez;
$n_tariffa_selez = "n_tariffa_selez" . $tariffa_selezionata;
if ($$n_tariffa_selez) $nome_tariffa = $$n_tariffa_selez;
} # fine if ($tariffa_selezionata)

$oggi = date("j/n/Y");

if ($sesso == "f") {
$il = "la";
$al = "alla";
$e = "a";
$o = "a";
$Mr = "s";
} # fine if ($sesso == "f")
else {
$il = "il";
$al = "al";
$a = "";
$o = "o";
$Mr = "";
} # fine else if ($sesso == "f")

if ($sesso2 == "f") {
$il2 = "la";
$al2 = "alla";
$e2 = "a";
$o2 = "a";
$Mr2 = "s";
} # fine if ($sesso2 == "f")
else {
$il2 = "il";
$al2 = "al";
$a2 = "";
$o2 = "o";
$Mr2 = "";
} # fine else if ($sesso2 == "f")

if (!$nome) { $nome = "<b>____________________</b>"; }
if (!$nome2) { $nome2 = "<b>____________________</b>"; }
if (!$cognome) { $cognome = "<b>_________________</b>"; }
if (!$cognome2) { $cognome2 = "<b>_________________</b>"; }
if (!$datanascita) $datanascita = "<b>______________</b>";
else $datanascita = formatta_data($datanascita,$stile_data);
if (!$datanascita2) $datanascita2 = "<b>______________</b>";
else $datanascita2 = formatta_data($datanascita2,$stile_data);
if (!$nazione) { $nazione = "<b>_____________</b>"; }
if (!$citta) { $citta = "<b>___________________</b>"; }
if (!$via) { $via2 = mex("via",$pag)." <b>________________________________</b>"; }
else { $via2 = $via; }
if (!$via) { $via = "<b>________________________________</b>"; }
if (!$numcivico) { $numcivico = "<b>_____</b>"; }
if (!$telefono) { $telefono = "<b>__________________</b>"; }
if (!$telefono2) { $telefono2 = "<b>__________________</b>"; }
if (!$telefono3) { $telefono3 = "<b>__________________</b>"; }
if (!$fax) { $fax = "<b>__________________</b>"; }
if (!$email) { $email = "<b>__________________</b>"; }
if (!$cap) { $cap = "<b>________</b>"; }
if ($num_persone == "non specificato" or $num_persone == "") {
$num_persone = "<b>_____</b>";
$num_persone_tot = "<b>_____</b>";
} # fine if ($num_persone == "non specificato" or $num_persone == "")
else { $num_persone_tot = $num_persone + $n_letti_agg; }
if ($costo_tot and $caparra) {
$resto_caparra = $costo_tot - $caparra;
$resto_caparra_p = punti_in_num($resto_caparra,$stile_soldi);
} # fine if ($costo_tot and $caparra)
else {
$resto_caparra = "<b>_____________</b>";
$resto_caparra_p = "<b>_____________</b>";
} # fine else if ($costo_tot and $caparra)
if (!$caparra or $caparra == 0) {
$caparra = "<b>___________</b>";
$caparra_p = "<b>___________</b>";
} # fine if (!$caparra or $caparra == 0)
else { $caparra_p = punti_in_num($caparra,$stile_soldi); }
if (!$data_inizio) $data_inizio = "<b>______________</b>";
else $data_inizio = formatta_data($data_inizio,$stile_data);
if (!$data_fine) $data_fine = "<b>______________</b>";
else $data_fine = formatta_data($data_fine,$stile_data);
if (!$nome_tariffa) { $nome_tariffa = "<b>____________________</b>"; }
if (!$costo_tariffa) {
$costo_tariffa = "<b>____________________</b>";
$costo_tariffa_p = "<b>____________________</b>";
} # fine if (!$costo_tariffa)
else { $costo_tariffa_p = punti_in_num($costo_tariffa,$stile_soldi); }
if (!$sconto) {
$sconto = "<b>____________</b>";
$sconto_p = "<b>____________</b>";
} # fine if (!$sconto)
else { $sconto_p = punti_in_num($sconto,$stile_soldi); }
if (!$commento) { $commento = "<b>______________________</b>"; }
if (!$appartamento) { $appartamento = "<b>____</b>"; }
if (!$app_assegnabili) { $app_assegnabili = "<b>_________________</b>"; }
if (!$pagato) {
$pagato = "<b>_____________</b>";
$pagato_p = "<b>_____________</b>";
} # fine if (!$pagato)
else { $pagato_p = punti_in_num($pagato,$stile_soldi); }
if (!$costo_tot) {
$costo_tot = "<b>_____________</b>";
$costo_tot_p = "<b>_____________</b>";
} # fine if (!$costo_tot)
else { $costo_tot_p = punti_in_num($costo_tot,$stile_soldi); }
if (!$n_letti_agg) { $n_letti_agg = "<b>____</b>"; }

for ($numca = 0 ; $numca < $d_num_costi_aggiuntivi ; $numca = $numca + 1) {
$nome_costo_agg = nome_costo_agg . $numca;
$nome_costo_agg = $$nome_costo_agg;
$val_costo_agg = val_costo_agg . $numca;
$val_costo_agg = $$val_costo_agg;
$val_costo_agg_p = punti_in_num($val_costo_agg,$stile_soldi);
$tutti_i_costi_agg .= "$nome_costo_agg: $val_costo_agg<br>";
$tutti_i_costi_agg_p .= "$nome_costo_agg: $val_costo_agg_p<br>";
if ($num_costo_agg_sel == $numca) {
$nome_costo_agg_sel = $nome_costo_agg;
$valore_costo_agg_sel = $val_costo_agg;
$valore_costo_agg_sel_p = $val_costo_agg_p;
} # fine if ($num_costo_agg_sel == $numca)
} # fine for $numca

$surname = $cognome;
$name = $nome;
$birthday = $datanascita;
$nation = $nazione;
$city = $citta;
$street = $via;
$street2 = $via2;
$street_number = $numcivico;
$postal_code = $cap;
$telephone = $telefono;
$telephone2 = $telefono2;
$telephone3 = $telefono3;
$surname2 = $cognome2;
$name2 = $nome2;
$birthday2 = $datanascita2;
$people_num = $num_persone;
$extra_beds_num = $n_letti_agg;
$people_num_tot = $num_persone_tot;
$fare_tot = $costo_tot;
$deposit = $caparra;
$deposit_rest = $resto_caparra;
$starting_date = $data_inizio;
$ending_date = $data_fine;
$fare_name = $nome_tariffa;
$fare_price = $costo_tariffa;
$discount = $sconto;
$comment = $commento;
$apartment = $appartamento;
$apartment_list = $app_assegnabili;
$paid = $pagato;
$all_extra_costs = $tutti_i_costi_agg;
$sel_extra_cost_name = $nome_costo_agg_sel;
$sel_extra_cost_value = $valore_costo_agg_sel;
$today = $oggi;
$fare_tot_p = $costo_tot_p;
$deposit_p = $caparra_p;
$paid_p = $pagato_p;
$deposit_rest_p = $resto_caparra_p;
$fare_price_p = $costo_tariffa_p;
$all_extra_costs_p = $tutti_i_costi_agg_p;
$sel_extra_cost_value_p = $valore_costo_agg_sel_p;
$discount_p = $sconto_p;

if ($tipo_contratto == 1) { include ("./contr/contr01.php"); }
if ($tipo_contratto == 2) { include ("./contr/contr02.php"); }
if ($tipo_contratto == 3) { include ("./contr/contr03.php"); }
if ($tipo_contratto == 4) { include ("./contr/contr04.php"); }
if ($tipo_contratto == 5) { include ("./contr/contr05.php"); }
if ($tipo_contratto == 6) { include ("./contr/contr06.php"); }
if ($tipo_contratto == 7) { include ("./contr/contr07.php"); }
if ($tipo_contratto == 8) { include ("./contr/contr08.php"); }
if ($tipo_contratto == 9) { include ("./contr/contr09.php"); }
if ($tipo_contratto == 10) { include ("./contr/contr10.php"); }
if ($tipo_contratto == 11) { include ("./contr/contr11.php"); }
if ($tipo_contratto == 12) { include ("./contr/contr12.php"); }
if ($tipo_contratto == 13) { include ("./contr/contr13.php"); }
if ($tipo_contratto == 14) { include ("./contr/contr14.php"); }
if ($tipo_contratto == 15) { include ("./contr/contr15.php"); }
if ($tipo_contratto == 16) { include ("./contr/contr16.php"); }
if ($tipo_contratto == 17) { include ("./contr/contr17.php"); }
if ($tipo_contratto == 18) { include ("./contr/contr18.php"); }


echo $contratto;

?>

</body>
</html>
